==> wazo-auth_20.14~20200928.185040.24510b1.deb10.tar.xz: wazo-auth/integration_tests/suite/helpers/fixtures/http.py <==
# Copyright 2019-2020 The Wazo Authors  (see the AUTHORS file)
# SPDX-License-Identifier: GPL-3.0-or-later

import random
import string

import requests

from functools import wraps


def _random_string(length):
    return ''.join(random.choice(string.ascii_lowercase) for _ in range(length))


def admin_client(**decorator_args):
    decorator_args.setdefault('tenant_name', _random_string(9))
    decorator_args.setdefault('username', _random_string(5))

    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            creator = self.client.users.new(username='creator', password='opensesame')
            policy = self.client.policies.new('tmp', acl_templates=['auth.#'])
            self.client.users.add_policy(creator['uuid'], policy['uuid'])

            creator_client = self.new_auth_client(
                username='creator', password='opensesame'
            )
            creator_token = creator_client.token.new()
            creator_client.set_token(creator_token['token'])

            tenant = creator_client.tenants.new(name=decorator_args['tenant_name'])

            username, password = decorator_args['username'], 'secret'
            created_user = creator_client.users.new(
                username=username, password=password, tenant_uuid=tenant['uuid']
            )

            created_client = self.new_auth_client(username=username, password=password)
            created_token = created_client.token.new()
            created_client.set_token(created_token['token'])

            self.client.users.delete(creator['uuid'])
            self.client.policies.delete(policy['uuid'])

            result = decorated(self, created_client, *args, **kwargs)

            self.client.users.delete(created_user['uuid'])
            self.client.tenants.delete(tenant['uuid'])

            return result

        return wrapper

    return decorator


def tenant(**tenant_args):
    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            tenant = self.client.tenants.new(**tenant_args)
            try:
                result = decorated(self, tenant, *args, **kwargs)
            finally:
                try:
                    self.client.tenants.delete(tenant['uuid'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator


def token(**token_args):
    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            token_args.setdefault('backend', 'wazo_user')
            token_args.setdefault('expiration', 5)
            if 'access_type' in token_args:
                token_args.setdefault('client_id', _random_string(20))
            username = token_args.pop('username')
            password = token_args.pop('password')
            client = self.new_auth_client(username, password)
            token = client.token.new(**token_args)
            if 'client_id' in token_args:
                token['client_id'] = token_args['client_id']
            try:
                result = decorated(self, token, *args, **kwargs)
            finally:
                try:
                    self.client.token.revoke(token['token'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator


def user(**user_args):
    user_args.setdefault('username', _random_string(20))
    user_args.setdefault('password', _random_string(20))

    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            user = self.client.users.new(**user_args)
            try:
                result = decorated(self, user, *args, **kwargs)
            finally:
                try:
                    self.client.users.delete(user['uuid'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator


def user_register(**user_args):
    user_args.setdefault('username', _random_string(20))
    user_args.setdefault('password', _random_string(20))
    user_args.setdefault(
        'email_address', '{}@example.com'.format(user_args['username'])
    )

    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            user = self.client.users.register(**user_args)
            try:
                result = decorated(self, user, *args, **kwargs)
            finally:
                try:
                    self.client.users.delete(user['uuid'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator


def policy(**policy_args):
    policy_args.setdefault('name', _random_string(20))
    policy_args['acl_templates'] = policy_args.get('acl_templates') or []

    def set_policy_config_managed(db_client, policy_uuid):
        with db_client.connect() as connection:
            connection.execute(
                f"UPDATE auth_policy set config_managed=true WHERE uuid = '{policy_uuid}'"
            )

    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            policy = self.client.policies.new(**policy_args)
            if policy_args.get('config_managed'):
                db_client = self.new_db_client()
                set_policy_config_managed(db_client, policy['uuid'])
            try:
                result = decorated(self, policy, *args, **kwargs)
            finally:
                try:
                    self.client.policies.delete(policy['uuid'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator


def group(**group_args):
    group_args.setdefault('name', _random_string(20))

    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            group = self.client.groups.new(**group_args)
            try:
                result = decorated(self, group, *args, **kwargs)
            finally:
                try:
                    self.client.groups.delete(group['uuid'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator


def session(**session_args):
    user_args = {'username': _random_string(20), 'password': 'pass'}
    if 'tenant_uuid' in session_args:
        user_args['tenant_uuid'] = session_args['tenant_uuid']
    token_args = {'session_type': 'mobile' if session_args.get('mobile') else None}

    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            user = self.client.users.new(**user_args)
            client = self.new_auth_client(user_args['username'], user_args['password'])
            token = client.token.new(**token_args)
            session = self.client.users.get_sessions(user['uuid'])['items'][0]
            try:
                result = decorated(self, session, *args, **kwargs)
            finally:
                try:
                    self.client.users.delete(user['uuid'])
                    self.client.token.revoke(token['token'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator

==> wazo-auth_21.04~20210323.142343.48bb999.deb10.tar.xz: wazo-auth/integration_tests/suite/helpers/fixtures/http.py <==
# Copyright 2019-2021 The Wazo Authors  (see the AUTHORS file)
# SPDX-License-Identifier: GPL-3.0-or-later

import random
import string

import requests

from contextlib import contextmanager
from functools import wraps


def _random_string(length):
    return ''.join(random.choice(string.ascii_lowercase) for _ in range(length))


def admin_client(**decorator_args):
    decorator_args.setdefault('tenant_name', _random_string(9))
    decorator_args.setdefault('username', _random_string(5))

    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            creator = self.client.users.new(username='creator', password='opensesame')
            policy = self.client.policies.new('tmp', acl=['auth.#'])
            self.client.users.add_policy(creator['uuid'], policy['uuid'])

            creator_client = self.new_auth_client(
                username='creator', password='opensesame'
            )
            creator_token = creator_client.token.new()
            creator_client.set_token(creator_token['token'])

            tenant = creator_client.tenants.new(
                name=decorator_args['tenant_name'], slug=decorator_args['tenant_slug']
            )

            username, password = decorator_args['username'], 'secret'
            created_user = creator_client.users.new(
                username=username, password=password, tenant_uuid=tenant['uuid']
            )

            created_client = self.new_auth_client(username=username, password=password)
            created_token = created_client.token.new()
            created_client.set_token(created_token['token'])

            self.client.users.delete(creator['uuid'])
            self.client.policies.delete(policy['uuid'])

            result = decorated(self, created_client, *args, **kwargs)

            self.client.users.delete(created_user['uuid'])
            self.client.tenants.delete(tenant['uuid'])

            return result

        return wrapper

    return decorator


def tenant(**tenant_args):
    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            tenant = self.client.tenants.new(**tenant_args)
            try:
                result = decorated(self, tenant, *args, **kwargs)
            finally:
                try:
                    self.client.tenants.delete(tenant['uuid'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator


def token(**token_args):
    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            token_args.setdefault('backend', 'wazo_user')
            token_args.setdefault('expiration', 5)
            if 'access_type' in token_args:
                token_args.setdefault('client_id', _random_string(20))
            username = token_args.pop('username')
            password = token_args.pop('password')
            client = self.new_auth_client(username, password)
            token = client.token.new(**token_args)
            if 'client_id' in token_args:
                token['client_id'] = token_args['client_id']
            try:
                result = decorated(self, token, *args, **kwargs)
            finally:
                try:
                    self.client.token.revoke(token['token'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator


def user(**user_args):
    user_args.setdefault('username', _random_string(20))
    user_args.setdefault('password', _random_string(20))

    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            user = self.client.users.new(**user_args)
            try:
                result = decorated(self, user, *args, **kwargs)
            finally:
                try:
                    self.client.users.delete(user['uuid'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator


def user_register(**user_args):
    user_args.setdefault('username', _random_string(20))
    user_args.setdefault('password', _random_string(20))
    user_args.setdefault(
        'email_address', '{}@example.com'.format(user_args['username'])
    )

    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            user = self.client.users.register(**user_args)
            try:
                result = decorated(self, user, *args, **kwargs)
            finally:
                try:
                    self.client.users.delete(user['uuid'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator


@contextmanager
def config_managed_policy(db_client, policy, policy_args):
    if policy_args.get('config_managed'):
        policy_uuid = policy['uuid']
        with db_client.connect() as connection:
            connection.execute(
                f"UPDATE auth_policy set config_managed=true WHERE uuid = '{policy_uuid}'"
            )
    yield


def policy(**policy_args):
    policy_args.setdefault('name', _random_string(20))
    policy_args['acl'] = policy_args.get('acl') or []

    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            policy = self.client.policies.new(**policy_args)
            try:
                with config_managed_policy(self.new_db_client(), policy, policy_args):
                    result = decorated(self, policy, *args, **kwargs)
            finally:
                try:
                    self.client.policies.delete(policy['uuid'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator


@contextmanager
def system_managed_group(db_client, group_uuid, group_args):
    if not group_args.get('system_managed'):
        yield
    else:
        with db_client.connect() as connection:
            connection.execute(
                f"UPDATE auth_group set system_managed=true WHERE uuid = '{group_uuid}'"
            )
        try:
            yield
        finally:
            with db_client.connect() as connection:
                connection.execute(
                    f"UPDATE auth_group set system_managed=false WHERE uuid = '{group_uuid}'"
                )


def group(**group_args):
    group_args.setdefault('name', _random_string(20))

    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            group = self.client.groups.new(**group_args)
            try:
                with system_managed_group(
                    self.new_db_client(), group['uuid'], group_args
                ):
                    result = decorated(self, group, *args, **kwargs)
            finally:
                try:
                    self.client.groups.delete(group['uuid'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator


def session(**session_args):
    user_args = {'username': _random_string(20), 'password': 'pass'}
    if 'tenant_uuid' in session_args:
        user_args['tenant_uuid'] = session_args['tenant_uuid']
    token_args = {'session_type': 'mobile' if session_args.get('mobile') else None}

    def decorator(decorated):
        @wraps(decorated)
        def wrapper(self, *args, **kwargs):
            user = self.client.users.new(**user_args)
            client = self.new_auth_client(user_args['username'], user_args['password'])
            token = client.token.new(**token_args)
            session = self.client.users.get_sessions(user['uuid'])['items'][0]
            try:
                result = decorated(self, session, *args, **kwargs)
            finally:
                try:
                    self.client.users.delete(user['uuid'])
                    self.client.token.revoke(token['token'])
                except requests.HTTPError:
                    pass
            return result

        return wrapper

    return decorator
